==> DBKGrad_1.01.tar.gz: DBKGrad/man/DBKGrad-package.Rd <==
\name{DBKGrad-package}
\alias{DBKGrad-package}
\docType{package}
\title{DBKGrad - Discrete Beta Kernel Graduation.}
\description{
This package allows for nonparametric graduation of mortality rates using the discrete beta kernel estimator in both its fixed (Mazza and Punzo, 2011) and adaptive (Mazza and Punzo, 2013, in press) variants.
}
\details{
\tabular{ll}{
Package: \tab DBKGraduation\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2012-08-16\cr
License: \tab GNU-2\cr
}
}
\references{
Elzhov TV, Mullen KM, Bolker B (2010) \emph{minpack.lm:} R Interface to the Levenberg-Marquardt Nonlinear Least-Squares Algorithm Found in MINPACK. R package version 1.1-5. URL http://CRAN.R-project.org/package=minpack.lm.

Bagnato L, Punzo A (in press) Finite Mixtures of Unimodal Beta and Gamma Densities and the k-Bumps Algorithm. \emph{Computational Statistics}.

Mazza A, Punzo A (2011) Discrete Beta Kernel Graduation of Age-Specific Demographic Indicators. In S Ingrassia, R Rocci, M Vichi (eds.), \emph{New Perspectives in Statistical Modeling and Data Analysis}, volume \bold{42} of \emph{Studies in Classification, Data Analysis and Knowledge Organization}, pp. 127-134. Springer-Verlag, Berlin-Heidelberg.

Mazza A, Punzo A (2013) Graduation by Adaptive Discrete Beta Kernels. In A Giusti, G Ritter, M Vichi (eds.), \emph{Classification and Data Mining}, volume \bold{44} of \emph{Studies in Classification, Data Analysis and Knowledge Organization}, pp. 77-84. Springer-Verlag, Berlin-Heidelberg.

Mazza A, Punzo A (in press) Using the Variation Coefficient for Adaptive Discrete Beta Kernel Graduation. In P Giudici, S Ingrassia, M Vichi (eds.), \emph{Advances in Statistical Modelling for Data Analysis, Studies in Classification, Data Analysis and Knowledge Organization}, Springer-Verlag, Berlin-Heidelberg.

More J (1978) The Levenberg-Marquardt Algorithm: Implementation and Theory. In G Watson (ed.), \emph{Numerical Analysis}, volume \bold{630} of \emph{Lecture Notes in Mathematics}, pp. 104-116. Springer- Verlag, Berlin-Heidelberg.

Punzo A (2010) Discrete Beta-type Models. In H Locarek-Junge, C Weihs (eds.), \emph{Classification as a Tool for Research}, volume \bold{40} of \emph{Studies in Classification, Data Analysis and Knowledge Organization}, pp. 253-261. Springer-Verlag, Berlin-Heidelberg.

Punzo A, Zini A (2012) Discrete Approximations of Continuous and Mixed Measures on a Compact Interval \emph{Statistical Papers}, \bold{53}(3), 563-575.
}
\author{
Angelo Mazza and Antonio Punzo

Maintainer: Angelo Mazza <a.mazza@unict.it>
}
%%\note{
%%  ~~further notes~~
%%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{dbkGrad}}, \code{\link{plot}}, \code{\link{Sicily2008M}}
}

==> DBKGrad_1.3.tar.gz: DBKGrad/man/DBKGrad-package.Rd <==
\name{DBKGrad-package}
\alias{DBKGrad-package}
\docType{package}
\title{DBKGrad - Discrete Beta Kernel Graduation}
\description{
This package allows for nonparametric graduation of mortality rates using the discrete beta kernel estimator in both its fixed (Mazza and Punzo, 2011) and adaptive (Mazza and Punzo, 2013, in press) variants.
}
\details{
\tabular{ll}{
Package: \tab DBKGraduation\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2012-08-16\cr
License: \tab GNU-2\cr
}
}
\references{
Elzhov TV, Mullen KM, Bolker B (2010) \emph{minpack.lm:} R Interface to the Levenberg-Marquardt Nonlinear Least-Squares Algorithm Found in MINPACK. R package version 1.1-5. URL http://CRAN.R-project.org/package=minpack.lm.

Bagnato L, Punzo A (in press) Finite Mixtures of Unimodal Beta and Gamma Densities and the k-Bumps Algorithm. \emph{Computational Statistics}.

Mazza A, Punzo A (2011) Discrete Beta Kernel Graduation of Age-Specific Demographic Indicators. In S Ingrassia, R Rocci, M Vichi (eds.), \emph{New Perspectives in Statistical Modeling and Data Analysis}, volume \bold{42} of \emph{Studies in Classification, Data Analysis and Knowledge Organization}, pp. 127-134. Springer-Verlag, Berlin-Heidelberg.

Mazza A, Punzo A (2013) Graduation by Adaptive Discrete Beta Kernels. In A Giusti, G Ritter, M Vichi (eds.), \emph{Classification and Data Mining}, volume \bold{44} of \emph{Studies in Classification, Data Analysis and Knowledge Organization}, pp. 77-84. Springer-Verlag, Berlin-Heidelberg.

Mazza A, Punzo A (in press) Using the Variation Coefficient for Adaptive Discrete Beta Kernel Graduation. In P Giudici, S Ingrassia, M Vichi (eds.), \emph{Advances in Statistical Modelling for Data Analysis, Studies in Classification, Data Analysis and Knowledge Organization}, Springer-Verlag, Berlin-Heidelberg.

More J (1978) The Levenberg-Marquardt Algorithm: Implementation and Theory. In G Watson (ed.), \emph{Numerical Analysis}, volume \bold{630} of \emph{Lecture Notes in Mathematics}, pp. 104-116. Springer- Verlag, Berlin-Heidelberg.

Punzo A (2010) Discrete Beta-type Models. In H Locarek-Junge, C Weihs (eds.), \emph{Classification as a Tool for Research}, volume \bold{40} of \emph{Studies in Classification, Data Analysis and Knowledge Organization}, pp. 253-261. Springer-Verlag, Berlin-Heidelberg.

Punzo A, Zini A (2012) Discrete Approximations of Continuous and Mixed Measures on a Compact Interval \emph{Statistical Papers}, \bold{53}(3), 563-575.
}
\author{
Angelo Mazza and Antonio Punzo

Maintainer: Angelo Mazza <a.mazza@unict.it>
}
%%\note{
%%  ~~further notes~~
%%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{dbkGrad}}, \code{\link[DBKGrad:plot.dbkGrad]{plot}}, \code{\link{ItalyM}}
}
